==> autoscaling-common-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/autoscaling/common/IRandomGenerator.java <==
package software.amazon.awscdk.services.autoscaling.common;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:18:18.396Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IRandomGenerator extends software.amazon.jsii.JsiiSerializable {
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Boolean nextBoolean();
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number nextInt(final java.lang.Number min, final java.lang.Number max);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.autoscaling.common.IRandomGenerator {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public java.lang.Boolean nextBoolean() {
            return this.jsiiCall("nextBoolean", java.lang.Boolean.class);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public java.lang.Number nextInt(final java.lang.Number min, final java.lang.Number max) {
            return this.jsiiCall("nextInt", java.lang.Number.class, new Object[] { java.util.Objects.requireNonNull(min, "min is required"), java.util.Objects.requireNonNull(max, "max is required") });
        }
    }
}

==> autoscaling-common-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/autoscaling/common/IRandomGenerator.java <==
package software.amazon.awscdk.services.autoscaling.common;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:48:14.153Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IRandomGenerator extends software.amazon.jsii.JsiiSerializable {
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Boolean nextBoolean();

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number nextInt(final java.lang.Number min, final java.lang.Number max);


    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.autoscaling.common.IRandomGenerator {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public java.lang.Boolean nextBoolean() {
            return this.jsiiCall("nextBoolean", java.lang.Boolean.class);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public java.lang.Number nextInt(final java.lang.Number min, final java.lang.Number max) {
            return this.jsiiCall("nextInt", java.lang.Number.class, new Object[] { java.util.Objects.requireNonNull(min, "min is required"), java.util.Objects.requireNonNull(max, "max is required") });
        }
    }
}
